# Complex Network Representations for Coupled Dynamical Systems: Dynamical Networks

Install package as: 

    pip install dynamical_networks

See examples here: https://github.com/myersau3/Dynamical_Networks/tree/main/Examples

These examples are for simulating the power grid and manufacturer supplier networks.

This repository holds the Python code for analyzing and creating complex network representations of coupled dynamical systems.

<p align="center">
  <img src="sphinx/source/MS_network_gif.gif" width="400">
</p> <em>Example coupled dynamical system represented using a complex network with each node as a state variable's dynamics and edges weighted between coupled variables.</em>

